"""This is the "nester.py" module, and it provides one function called print_lol() which prints lists that may or may not include nested lists."""

def print_lol(the_list, indent=False, level=0):
        """This function takes a positional argument called "the_list" which is any Python list (of, possibly nested lists).
           Each data item in the provided list is (recursively) printed to the screen on its own line. A second argument called
           "indent" is used to determine if indenting is required. Its default value is False. A third argument called
           "level" is used to insert tab_stops when a nested list is encountered."""
        for each_item in the_list:
                if isinstance(each_item, list):
                        print_lol(each_item, indent, level+1)
                else:
                        if indent:
                                for tab_stop in range(level):
                                        print("\t", end='')
                                print(each_item)
                        else:
                                print(each_item)



from distutils.core import setup

setup(
	name		= 'alpha_nest',
	version		= '1.3.0',
	py_modules	= ['alpha_nest'],
	author		= 'Alpha Diallo',
	author_email	= 'diallo.omr.alpha@gmail.com',
	url		= 'http://www.headfirstlabs.com',
	description	= 'A simple printer of nested lists',
)
